django-htcpcp-tea
=================

.. image:: https://travis-ci.com/blueschu/django-htcpcp-tea.svg?branch=master
    :target: https://travis-ci.com/blueschu/django-htcpcp-tea
    :alt: Travis CI Build

.. image:: https://coveralls.io/repos/github/blueschu/django-htcpcp-tea/badge.svg?branch=master
    :target: https://coveralls.io/github/blueschu/django-htcpcp-tea?branch=master
    :alt: Coverage

.. image:: https://img.shields.io/pypi/pyversions/django-htcpcp-tea.svg
    :alt: PyPI - Python Version

.. image:: https://img.shields.io/pypi/djversions/django-htcpcp-tea.svg
    :alt: PyPI - Django Version

.. image:: https://img.shields.io/github/license/blueschu/django-htcpcp-tea.svg
    :target: ./LICENSE
    :alt: License

A Django app that implements the TEA extension to HTCPCP as defined in `RFC 7168`_.

.. _RFC 7168: https://tools.ietf.org/html/rfc7168

References
----------

- `[RFC 2324] Hyper Text Coffee Pot Control Protocol (HTCPCP/1.0)`_
- `[RFC 7158] The Hyper Text Coffee Pot Control Protocol for Tea Efflux Appliances (HTCPCP-TEA)`_
- `[RFC 2295] Transparent Content Negotiation in HTTP`_
- `MDN Web Docs | HTTP repsonse codes`_

.. _[RFC 2324] Hyper Text Coffee Pot Control Protocol (HTCPCP/1.0): https://tools.ietf.org/html/rfc2324
.. _[RFC 7158] The Hyper Text Coffee Pot Control Protocol for Tea Efflux Appliances (HTCPCP-TEA): https://tools.ietf.org/html/rfc7168
.. _[RFC 2295] Transparent Content Negotiation in HTTP: https://tools.ietf.org/html/rfc2295
.. _MDN Web Docs | HTTP repsonse codes: https://developer.mozilla.org/en-US/docs/Web/HTTP/Status

Related Work
------------

- Shane Brunswick's `Save 418 Movement`_.
- Dash Winterson's `HTCPCP Middleware (django-htcpcp)`_

.. _Save 418 Movement: http://save418.com/
.. _HTCPCP Middleware (django-htcpcp): https://github.com/dashdanw/django-htcpcp

License
-------

This software is licensed under the `MIT License`_. For more
information, read the file `LICENSE`_.

.. _MIT License: https://opensource.org/licenses/MIT
.. _LICENSE: ./LICENSE
